@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*-  */
 /*
  * OutputEditorHOCR.cc
- * Copyright (C) 2013-2022 Sandro Mani <manisandro@gmail.com>
+ * Copyright (C) 2013-2024 Sandro Mani <manisandro@gmail.com>
  *
  * gImageReader is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -279,7 +279,7 @@ void OutputEditorHOCR::HOCRBatchProcessor::appendOutput(std::ostream& dev, tesse
 	attrs["image"] = Glib::ustring::compose("'%1'", Glib::path_get_basename(pageInfos.filename));
 	attrs["ppageno"] = Glib::ustring::compose("%1", pageInfos.page);
 	attrs["rot"] = Glib::ustring::compose("%1", pageInfos.angle);
-	attrs["res"] = Glib::ustring::compose("%1", pageInfos.resolution);
+	attrs["scan_res"] = Glib::ustring::compose("%1", pageInfos.resolution);
 	pageDiv->set_attribute("title", HOCRItem::serializeAttrGroup(attrs));
 	doc->write_to_stream(dev);
 }
@@ -556,7 +556,7 @@ void OutputEditorHOCR::addPage(const Glib::ustring& hocrText, HOCRReadSessionDat
 	attrs["image"] = Glib::ustring::compose("'%1'", data.pageInfo.filename);
 	attrs["ppageno"] = Glib::ustring::compose("%1", data.pageInfo.page);
 	attrs["rot"] = Glib::ustring::compose("%1", data.pageInfo.angle);
-	attrs["res"] = Glib::ustring::compose("%1", data.pageInfo.resolution);
+	attrs["scan_res"] = Glib::ustring::compose("%1", data.pageInfo.resolution);
 	pageDiv->set_attribute("title", HOCRItem::serializeAttrGroup(attrs));
 
 	Gtk::TreeIter index = m_document->insertPage(data.insertIndex, pageDiv, true);
@@ -926,7 +926,7 @@ void OutputEditorHOCR::showTreeWidgetContextMenu(GdkEventButton* ev) {
 		}
 		CONNECT(&menu, hide, [&] { loop->quit(); });
 		menu.show_all();
-		menu.popup(ev->button, ev->time);
+		menu.popup_at_pointer((GdkEvent*)ev);
 		loop->run();
 		// Nothing else is allowed with multiple items selected
 		return;
@@ -987,7 +987,7 @@ void OutputEditorHOCR::showTreeWidgetContextMenu(GdkEventButton* ev) {
 	Glib::RefPtr<Glib::MainLoop> loop = Glib::MainLoop::create();
 	CONNECT(&menu, hide, [&] { loop->quit(); });
 	menu.show_all();
-	menu.popup(ev->button, ev->time);
+	menu.popup_at_pointer((GdkEvent*)ev);
 	loop->run();
 }
 
@@ -1160,7 +1160,7 @@ bool OutputEditorHOCR::exportToODT() {
 	std::string suggestion = m_filebasename;
 	if(suggestion.empty()) {
 		std::vector<Source*> sources = MAIN->getSourceManager()->getSelectedSources();
-		suggestion = !sources.empty() ? Glib::path_get_basename(sources.front()->displayname) : _("output");
+		suggestion = !sources.empty() ? Utils::split_filename(Glib::path_get_basename(sources.front()->displayname)).first : _("output");
 	}
 
 	FileDialogs::FileFilter filter = {_("OpenDocument Text Documents"), {"application/vnd.oasis.opendocument.text"}, {"*.odt"}};
@@ -1196,7 +1196,7 @@ bool OutputEditorHOCR::exportToPDF() {
 	std::string suggestion = m_filebasename;
 	if(suggestion.empty()) {
 		std::vector<Source*> sources = MAIN->getSourceManager()->getSelectedSources();
-		suggestion = !sources.empty() ? Glib::path_get_basename(sources.front()->displayname) : _("output");
+		suggestion = !sources.empty() ? Utils::split_filename(Glib::path_get_basename(sources.front()->displayname)).first : _("output");
 	}
 
 	std::string outname;
@@ -1226,7 +1226,7 @@ bool OutputEditorHOCR::exportToText() {
 	std::string suggestion = m_filebasename;
 	if(suggestion.empty()) {
 		std::vector<Source*> sources = MAIN->getSourceManager()->getSelectedSources();
-		suggestion = !sources.empty() ? Glib::path_get_basename(sources.front()->displayname) : _("output");
+		suggestion = !sources.empty() ? Utils::split_filename(Glib::path_get_basename(sources.front()->displayname)).first : _("output");
 	}
 
 	FileDialogs::FileFilter filter = {_("Text Files"), {"text/plain"}, {"*.txt"}};
