@@ -5,7 +5,7 @@
  *   Copyright (C) 2009-2013 Canonical Ltd.
  *   Author: Robert Ancell <robert.ancell@canonical.com>
  * Modifications are:
- *   Copyright (C) 2013-2022 Sandro Mani <manisandro@gmail.com>
+ *   Copyright (C) 2013-2024 Sandro Mani <manisandro@gmail.com>
  *
  * gImageReader is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -542,6 +542,8 @@ void ScannerSane::doCompletePage() {
 void ScannerSane::doStop() {
 	if(m_job != nullptr) {
 		if(m_job->handle != nullptr) {
+			g_debug("sane_cancel()");
+			sane_cancel(m_job->handle);
 			g_debug("sane_close()");
 			sane_close(m_job->handle);
 		}
