@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*-  */
 /*
  * OutputEditorHOCR.cc
- * Copyright (C) 2013-2022 Sandro Mani <manisandro@gmail.com>
+ * Copyright (C) 2013-2024 Sandro Mani <manisandro@gmail.com>
  *
  * gImageReader is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -265,7 +265,7 @@ void OutputEditorHOCR::HOCRBatchProcessor::appendOutput(QIODevice* dev, tesserac
 	attrs["image"] = QString("'./%1'").arg(QFileInfo(pageInfos.filename).fileName());
 	attrs["ppageno"] = QString::number(pageInfos.page);
 	attrs["rot"] = QString::number(pageInfos.angle);
-	attrs["res"] = QString::number(pageInfos.resolution);
+	attrs["scan_res"] = QString::number(pageInfos.resolution);
 	pageDiv.setAttribute("title", HOCRItem::serializeAttrGroup(attrs));
 	dev->write(doc.toByteArray());
 }
@@ -434,7 +434,7 @@ void OutputEditorHOCR::addPage(const QString& hocrText, HOCRReadSessionData data
 	attrs["image"] = QString("'%1'").arg(data.pageInfo.filename);
 	attrs["ppageno"] = QString::number(data.pageInfo.page);
 	attrs["rot"] = QString::number(data.pageInfo.angle);
-	attrs["res"] = QString::number(data.pageInfo.resolution);
+	attrs["scan_res"] = QString::number(data.pageInfo.resolution);
 	pageDiv.setAttribute("title", HOCRItem::serializeAttrGroup(attrs));
 
 	QModelIndex index = m_document->insertPage(data.insertIndex, pageDiv, true);
